pub enum GetReferenceResponse {
Exact(Reference),
StartWith(Vec<Reference>),
}Expand description
The response for getting a git reference
Variants
Exact(Reference)
The reference data matching the specified reference
StartWith(Vec<Reference>)
If the reference doesn’t exist in the repository but existing refs start with ref they will be returned as an array. For example, a call to get the data for a branch named feature, which doesn’t exist, would return head refs including featureA and featureB which do.