pub struct Git { /* private fields */ }Expand description
reference to git operations associated with a github repo
Implementations
Sourceimpl Git
impl Git
Sourcepub fn tree<S>(&self, sha: S, recursive: bool) -> Future<TreeData>
pub fn tree<S>(&self, sha: S, recursive: bool) -> Future<TreeData>
list a git tree of files for this repo at a given sha https://developer.github.com/v3/git/trees/#get-a-tree https://developer.github.com/v3/git/trees/#get-a-tree-recursively
Sourcepub fn blob<S>(&self, sha: S) -> Future<Blob>
pub fn blob<S>(&self, sha: S) -> Future<Blob>
get the blob contents of a given sha https://developer.github.com/v3/git/blobs/#get-a-blob
Sourcepub fn reference<S>(&self, reference: S) -> Future<GetReferenceResponse>
pub fn reference<S>(&self, reference: S) -> Future<GetReferenceResponse>
get the git reference data of a given ref the specified reference must be formatted as as “heads/branch”, not just “branch” https://developer.github.com/v3/git/refs/#get-a-reference