pub struct HookCreateOptions { /* private fields */ }Expand description
options for creating a repository hook see this for githubs official documentation
Implementations
Sourceimpl HookCreateOptions
impl HookCreateOptions
Sourcepub fn builder<N>(name: N) -> HookCreateOptionsBuilder
pub fn builder<N>(name: N) -> HookCreateOptionsBuilder
creates a new builder instance with a hook name care should be taken with respect to the hook name as you can only use “web” or a valid service name listed here
Sourcepub fn web() -> HookCreateOptionsBuilder
pub fn web() -> HookCreateOptionsBuilder
use this for creating a builder for webhook options