pub struct IssueLabels { /* private fields */ }Expand description
Provides access to label operations available for an individual issue
Implementations
Sourceimpl IssueLabels
impl IssueLabels
Sourcepub fn add(&self, labels: Vec<&str>) -> Future<Vec<Label>>
pub fn add(&self, labels: Vec<&str>) -> Future<Vec<Label>>
add a set of labels to this issue ref