Notifications

Struct Notifications 

pub struct Notifications { /* private fields */ }
Provides access to notifications. See the github docs for more information.

Implementations

Source

impl Notifications

pub fn list(&self, options: &ThreadListOptions) -> Future<Vec<Thread>>

List the authenticated user’s notifications.

See the github docs for more information.

pub fn list_for_repo<O, R>( &self, owner: O, repo: R, options: &ThreadListOptions, ) -> Future<Vec<Thread>>
where O: Into<String>, R: Into<String>,

List the authenticated user’s notifications for a repository.

See the github docs for more information.

pub fn mark_as_read<S>(&self, last_read_at: S) -> Future<()>
where S: Into<Option<String>>,

Mark notifications as read. Default: now

See the github docs for more information.

pub fn mark_as_read_for_repo<O, R, S>( &self, owner: O, repo: R, last_read_at: S, ) -> Future<()>
where O: Into<String>, R: Into<String>, S: Into<Option<String>>,

Mark notifications as read in a repository. Default: now

See github docs for more information.

pub fn get_thread<S>(&self, id: S) -> Future<Thread>
where S: Into<String>,

Return a single thread.

See the github docs for more information.

pub fn mark_thread_as_read<S>(&self, id: S) -> Future<()>
where S: Into<String>,

Mark a thread as read

See the github docs for more information.

pub fn get_subscription<S>(&self, id: S) -> Future<Subscription>
where S: Into<String>,

Return the subscription information for a thread.

See the github docs for more information.

pub fn subscribe<S>(&self, id: S) -> Future<Subscription>
where S: Into<String>,

Subscribe to a thread and return the subscription information.

See the github docs for more information.

pub fn unsubscribe<S>(&self, id: S) -> Future<Subscription>
where S: Into<String>,

Unsubscribe to a thread and return the subscription information.

See the github docs for more information.

pub fn delete_subscription<S>(&self, id: S) -> Future<()>
where S: Into<String>,

Delete the thread subscription.

See the github docs for more information.