pub struct PullRequests { /* private fields */ }Expand description
A structure for interfacing with a repositories list of pull requests
Implementations
Sourceimpl PullRequests
impl PullRequests
Sourcepub fn get(&self, number: u64) -> PullRequest
pub fn get(&self, number: u64) -> PullRequest
Get a reference to a structure for interfacing with a specific pull request
Sourcepub fn create(&self, pr: &PullOptions) -> Future<Pull>
pub fn create(&self, pr: &PullOptions) -> Future<Pull>
Create a new pull request
Sourcepub fn iter(&self, options: &PullListOptions) -> Stream<Pull>
pub fn iter(&self, options: &PullListOptions) -> Stream<Pull>
provides a stream over all pages of pull requests