Git

Struct Git 

pub struct Git { /* private fields */ }
reference to git operations associated with a github repo

Implementations

Source

impl Git

pub fn tree<S>(&self, sha: S, recursive: bool) -> Future<TreeData>
where S: Into<String>,

list a git tree of files for this repo at a given sha https://developer.github.com/v3/git/trees/#get-a-tree https://developer.github.com/v3/git/trees/#get-a-tree-recursively

pub fn blob<S>(&self, sha: S) -> Future<Blob>
where S: Into<String>,

get the blob contents of a given sha https://developer.github.com/v3/git/blobs/#get-a-blob

pub fn reference<S>(&self, reference: S) -> Future<GetReferenceResponse>
where S: Into<String>,

get the git reference data of a given ref the specified reference must be formatted as as “heads/branch”, not just “branch” https://developer.github.com/v3/git/refs/#get-a-reference

pub fn delete_reference<S>(&self, reference: S) -> Future<()>
where S: Into<String>,

branches should be in the format heads/feature-a tags should be in the format tags/v1.0 https://developer.github.com/v3/git/refs/#delete-a-reference