pub struct Issues { /* private fields */ }Expand description
Provides access to operations available for a repository issues
Typically accessed via github.repo(..., ...).issues()
Implementations
Sourceimpl Issues
impl Issues
Sourcepub fn new<O, R>(github: Github, owner: O, repo: R) -> Self
pub fn new<O, R>(github: Github, owner: O, repo: R) -> Self
create a new instance of a github repo issue ref
pub fn get(&self, number: u64) -> IssueRef
pub fn create(&self, is: &IssueOptions) -> Future<Issue>
pub fn update(&self, number: &u64, is: &IssueOptions) -> Future<Issue>
Sourcepub fn list(&self, options: &IssueListOptions) -> Future<Vec<Issue>>
pub fn list(&self, options: &IssueListOptions) -> Future<Vec<Issue>>
Return the first page of issues for this repisotiry See the github docs for more information
Sourcepub fn iter(&self, options: &IssueListOptions) -> Stream<Issue>
pub fn iter(&self, options: &IssueListOptions) -> Stream<Issue>
Return a stream of all issues for this repository
See the github docs for more information
Note: You’ll typically want to use a IssueListOptions with a per_page
of 100 for maximum api credential rate limit efficency