pub struct Notifications { /* private fields */ }Expand description
Provides access to notifications. See the github docs for more information.
Implementations
Sourceimpl Notifications
impl Notifications
Sourcepub fn list(&self, options: &ThreadListOptions) -> Future<Vec<Thread>>
pub fn list(&self, options: &ThreadListOptions) -> Future<Vec<Thread>>
List the authenticated user’s notifications.
See the github docs for more information.
Sourcepub fn list_for_repo<O, R>(
&self,
owner: O,
repo: R,
options: &ThreadListOptions,
) -> Future<Vec<Thread>>
pub fn list_for_repo<O, R>( &self, owner: O, repo: R, options: &ThreadListOptions, ) -> Future<Vec<Thread>>
List the authenticated user’s notifications for a repository.
See the github docs for more information.
Sourcepub fn mark_as_read<S>(&self, last_read_at: S) -> Future<()>
pub fn mark_as_read<S>(&self, last_read_at: S) -> Future<()>
Mark notifications as read. Default: now
See the github docs for more information.
Sourcepub fn mark_as_read_for_repo<O, R, S>(
&self,
owner: O,
repo: R,
last_read_at: S,
) -> Future<()>
pub fn mark_as_read_for_repo<O, R, S>( &self, owner: O, repo: R, last_read_at: S, ) -> Future<()>
Mark notifications as read in a repository. Default: now
See github docs for more information.
Sourcepub fn get_thread<S>(&self, id: S) -> Future<Thread>
pub fn get_thread<S>(&self, id: S) -> Future<Thread>
Return a single thread.
See the github docs for more information.
Sourcepub fn mark_thread_as_read<S>(&self, id: S) -> Future<()>
pub fn mark_thread_as_read<S>(&self, id: S) -> Future<()>
Mark a thread as read
See the github docs for more information.
Sourcepub fn get_subscription<S>(&self, id: S) -> Future<Subscription>
pub fn get_subscription<S>(&self, id: S) -> Future<Subscription>
Return the subscription information for a thread.
See the github docs for more information.
Sourcepub fn subscribe<S>(&self, id: S) -> Future<Subscription>
pub fn subscribe<S>(&self, id: S) -> Future<Subscription>
Subscribe to a thread and return the subscription information.
See the github docs for more information.
Sourcepub fn unsubscribe<S>(&self, id: S) -> Future<Subscription>
pub fn unsubscribe<S>(&self, id: S) -> Future<Subscription>
Unsubscribe to a thread and return the subscription information.
See the github docs for more information.
Sourcepub fn delete_subscription<S>(&self, id: S) -> Future<()>
pub fn delete_subscription<S>(&self, id: S) -> Future<()>
Delete the thread subscription.
See the github docs for more information.