pub struct Github { /* private fields */ }Expand description
Entry point interface for interacting with GitHub API
Implementations
Sourceimpl Github
impl Github
pub fn new<A, C>(agent: A, credentials: C) -> Result<Self>
pub fn host<H, A, C>(host: H, agent: A, credentials: C) -> Result<Self>
pub fn custom<H, A, CR>( host: H, agent: A, credentials: CR, http: Client, ) -> Self
pub fn set_credentials<CR>(&mut self, credentials: CR)
pub fn rate_limit(&self) -> RateLimit
Sourcepub fn repo<O, R>(&self, owner: O, repo: R) -> Repository
pub fn repo<O, R>(&self, owner: O, repo: R) -> Repository
Return a reference to a Github repository
Sourcepub fn user_repos<S>(&self, owner: S) -> UserRepositories
pub fn user_repos<S>(&self, owner: S) -> UserRepositories
Return a reference to the collection of repositories owned by and associated with an owner
Sourcepub fn repos(&self) -> Repositories
pub fn repos(&self) -> Repositories
Return a reference to the collection of repositories owned by the user associated with the current authentication credentials
pub fn org<O>(&self, org: O) -> Organization
Sourcepub fn orgs(&self) -> Organizations
pub fn orgs(&self) -> Organizations
Return a reference to the collection of organizations that the user associated with the current authentication credentials is in
Sourcepub fn users(&self) -> Users
pub fn users(&self) -> Users
Return a reference to an interface that provides access to user information.
Sourcepub fn user_orgs<U>(&self, user: U) -> UserOrganizations
pub fn user_orgs<U>(&self, user: U) -> UserOrganizations
Return a reference to the collection of organizations a user is publicly associated with
Sourcepub fn user_gists<O>(&self, owner: O) -> UserGists
pub fn user_gists<O>(&self, owner: O) -> UserGists
Return a reference to an interface that provides access to a user’s gists
Sourcepub fn gists(&self) -> Gists
pub fn gists(&self) -> Gists
Return a reference to an interface that provides access to the gists belonging to the owner of the token used to configure this client
Sourcepub fn search(&self) -> Search
pub fn search(&self) -> Search
Return a reference to an interface that provides access to search operations
Sourcepub fn org_repos<O>(&self, org: O) -> OrganizationRepositories
pub fn org_repos<O>(&self, org: O) -> OrganizationRepositories
Return a reference to the collection of repositories owned by and associated with an organization